pub enum Brush<I = ImageBrush, G = Gradient> {
Solid(AlphaColor<Srgb>),
Gradient(G),
Image(I),
}Expand description
Describes the color content of a filled or stroked shape.
See also BrushRef which can be used to avoid allocations.
Variants
Implementations
Sourceimpl Brush
impl Brush
Sourcepub fn with_alpha(self, alpha: f32) -> Brush
pub fn with_alpha(self, alpha: f32) -> Brush
Returns the brush with the alpha component set to alpha.
Sourcepub fn multiply_alpha(self, alpha: f32) -> Brush
pub fn multiply_alpha(self, alpha: f32) -> Brush
Returns the brush with the alpha component multiplied by alpha.
The behaviour of this transformation is undefined if alpha is negative.
If any resulting alphas would overflow, these currently saturate (to opaque).