pub struct Stroke {
pub width: f64,
pub join: Join,
pub miter_limit: f64,
pub start_cap: Cap,
pub end_cap: Cap,
pub dash_pattern: SmallVec<[f64; 4]>,
pub dash_offset: f64,
}Expand description
The visual style of a stroke.
Fields
width: f64Width of the stroke.
join: JoinStyle for connecting segments of the stroke.
miter_limit: f64Limit for miter joins.
start_cap: CapStyle for capping the beginning of an open subpath.
end_cap: CapStyle for capping the end of an open subpath.
dash_pattern: SmallVec<[f64; 4]>Lengths of dashes in alternating on/off order.
dash_offset: f64Offset of the first dash.
Implementations
Sourceimpl Stroke
impl Stroke
Sourcepub const fn with_miter_limit(self, limit: f64) -> Stroke
pub const fn with_miter_limit(self, limit: f64) -> Stroke
Builder method for setting the limit for miter joins.
Sourcepub const fn with_start_cap(self, cap: Cap) -> Stroke
pub const fn with_start_cap(self, cap: Cap) -> Stroke
Builder method for setting the cap style for the start of the stroke.
Sourcepub const fn with_end_cap(self, cap: Cap) -> Stroke
pub const fn with_end_cap(self, cap: Cap) -> Stroke
Builder method for setting the cap style for the end of the stroke.
Sourcepub fn with_dashes<P>(self, offset: f64, pattern: P) -> Stroke
pub fn with_dashes<P>(self, offset: f64, pattern: P) -> Stroke
Builder method for setting the dashing parameters.