icon_button

Function icon_button 

pub fn icon_button<State, F>(
    mark: impl Into<IconData>,
    label: impl Into<String>,
    on_press: F,
) -> IconButtonView<State>
where State: 'static, F: Fn(&mut State) + 'static,
Create a pressable vector icon painting mark, labelled label for accessibility, that runs on_press against the app state when released inside its bounds. See the module docs.