Memo

Struct Memo 

pub struct Memo<T, S = SyncStorage>
where S: Storage<T>,
{ /* private fields */ }
A memo is an efficient derived reactive value based on other reactive values.

Unlike a “derived signal,” a memo comes with two guarantees:

  1. The memo will only run once per change, no matter how many times you access its value.
  2. The memo will only notify its dependents if the value of the computation changes.

This makes a memo the perfect tool for expensive computations.

Memos have a certain overhead compared to derived signals. In most cases, you should create a derived signal. But if the derivation calculation is expensive, you should create a memo.

Memos are lazy: they do not run at all until they are read for the first time, and they will not re-run the calculation when a source signal changes until they are read again.

This is an arena-allocated type, which is Copy and is disposed when its reactive Owner cleans up. For a reference-counted signal that lives as as long as a reference to it is alive, see ArcMemo.

let (value, set_value) = signal(0);

// 🆗 we could create a derived signal with a simple function
let double_value = move || value.get() * 2;
set_value.set(2);
assert_eq!(double_value(), 4);

// but imagine the computation is really expensive
let expensive = move || really_expensive_computation(value.get()); // lazy: doesn't run until called
Effect::new(move |_| {
  // 🆗 run #1: calls `really_expensive_computation` the first time
  println!("expensive = {}", expensive());
});
Effect::new(move |_| {
  // ❌ run #2: this calls `really_expensive_computation` a second time!
  let value = expensive();
  // do something else...
});

// instead, we create a memo
// 🆗 run #1: the calculation runs once immediately
let memoized = Memo::new(move |_| really_expensive_computation(value.get()));
Effect::new(move |_| {
  // 🆗 reads the current value of the memo
  //    can be `memoized()` on nightly
  println!("memoized = {}", memoized.get());
});
Effect::new(move |_| {
  // ✅ reads the current value **without re-running the calculation**
  let value = memoized.get();
  // do something else...
});

Core Trait Implementations

  • .get() clones the current value of the memo. If you call it within an effect, it will cause that effect to subscribe to the memo, and to re-run whenever the value of the memo changes.
  • .read() returns a guard that allows accessing the value of the memo by reference. If you call it within an effect, it will cause that effect to subscribe to the memo, and to re-run whenever the value of the memo changes.
    • .read_untracked() gives access to the current value of the memo without reactively tracking it.
  • .with() allows you to reactively access the memo’s value without cloning by applying a callback function.
    • .with_untracked() allows you to access the memo’s value by applying a callback function without reactively tracking it.
  • .to_stream() converts the memo to an async stream of values.
  • ::from_stream() converts an async stream of values into a memo containing the latest value.

Implementations

Source

impl<T> Memo<T>
where T: Send + Sync + 'static,

pub fn new(fun: impl Fn(Option<&T>) -> T + Send + Sync + 'static) -> Memo<T>
where T: PartialEq,

Creates a new memoized, computed reactive value.

As with an Effect, the argument to the memo function is the previous value, i.e., the current value of the memo, which will be None for the initial calculation.

let (value, set_value) = signal(0);

// the memo will reactively update whenever `value` changes
let memoized =
    Memo::new(move |_| really_expensive_computation(value.get()));
pub fn new_with_compare( fun: impl Fn(Option<&T>) -> T + Send + Sync + 'static, changed: fn(Option<&T>, Option<&T>) -> bool, ) -> Memo<T>

Creates a new memo with a custom comparison function. By default, memos simply use PartialEq to compare the previous value to the new value. Passing a custom comparator allows you to compare the old and new values using any criteria.

changed should be a function that returns true if the new value is different from the old value.

pub fn new_owning( fun: impl Fn(Option<T>) -> (T, bool) + Send + Sync + 'static, ) -> Memo<T>

Creates a new memo by passing a function that computes the value.

Unlike Memo::new, this receives ownership of the previous value. As a result, it must return both the new value and a bool that is true if the value has changed.

This is lazy: the function will not be called until the memo’s value is read for the first time.