Stroke

Struct Stroke 

pub struct Stroke {
    pub width: f64,
    pub join: Join,
    pub miter_limit: f64,
    pub start_cap: Cap,
    pub end_cap: Cap,
    pub dash_pattern: SmallVec<[f64; 4]>,
    pub dash_offset: f64,
}
The visual style of a stroke.

Fields

width: f64

Width of the stroke.

join: Join

Style for connecting segments of the stroke.

miter_limit: f64

Limit for miter joins.

start_cap: Cap

Style for capping the beginning of an open subpath.

end_cap: Cap

Style for capping the end of an open subpath.

dash_pattern: SmallVec<[f64; 4]>

Lengths of dashes in alternating on/off order.

dash_offset: f64

Offset of the first dash.

Implementations

Source

impl Stroke

pub const fn new(width: f64) -> Stroke

Creates a new stroke with the specified width.

pub const fn with_join(self, join: Join) -> Stroke

Builder method for setting the join style.

pub const fn with_miter_limit(self, limit: f64) -> Stroke

Builder method for setting the limit for miter joins.

pub const fn with_start_cap(self, cap: Cap) -> Stroke

Builder method for setting the cap style for the start of the stroke.

pub const fn with_end_cap(self, cap: Cap) -> Stroke

Builder method for setting the cap style for the end of the stroke.

pub const fn with_caps(self, cap: Cap) -> Stroke

Builder method for setting the cap style.

pub fn with_dashes<P>(self, offset: f64, pattern: P) -> Stroke
where P: IntoIterator, <P as IntoIterator>::Item: Borrow<f64>,

Builder method for setting the dashing parameters.

pub fn is_finite(&self) -> bool

Returns true if all floating-point stroke parameters are finite.

pub fn is_nan(&self) -> bool

Returns true if any floating-point stroke parameter is NaN.